      function [scales] = scale (sx, sy, sz)
%     -----------------------------------------
%     Scale an image, use equal scales for zoom
%     -----------------------------------------
%     scale = operator sub-set of finite motion matrix
%     sx    = scale in x-direction
%     sy    = scale in y-direction
%     sz    = scale in z-direction
%     For zoom make sx = sy = sz
      scales      = eye(3,3) ; % gives no change
      scales(1,1) = sx;
      scales(2,2) = sy;
      scales(3,3) = sz;
%     end of scale
